@@ -81,14 +81,14 @@ class NelsonAalenFitter(object):
 
     def _variance_f_smooth(self, population, deaths):
         df = pd.DataFrame( {'N':population, 'd':deaths})
-        return df.apply( lambda (N,d): np.sum([1./(N-i)**2 for i in range(int(d))]), axis=1 )
+        return df.apply( lambda N_d: np.sum([1./(N_d[0]-i)**2 for i in range(int(N_d[1]))]), axis=1 )
 
     def _variance_f_discrete(self, population, deaths):
         return 1.*(population-deaths)*deaths/population**3
 
     def _additive_f_smooth(self, population, deaths):
         df = pd.DataFrame( {'N':population, 'd':deaths})
-        return df.apply( lambda (N,d): np.sum([1./(N-i) for i in range(int(d))]), axis=1 )
+        return df.apply( lambda N_d: np.sum([1./(N_d[0]-i) for i in range(int(N_d[1]))]), axis=1 )
 
     def _additive_f_discrete(self, population, deaths):
        return (1.*deaths/population).replace([np.inf],0)
