@@ -1,3 +1,5 @@
+from __future__ import print_function
+
 #plotting 
 import numpy as np
 from matplotlib import pyplot as plt
@@ -16,7 +18,7 @@ def plot_lifetimes(lifetimes, censorship = None, birthtimes=None, order=False):
     """
     N = lifetimes.shape[0]
     if N>100:
-      print "warning: you may want to subsample to less than 100 individuals."
+      print("warning: you may want to subsample to less than 100 individuals.")
 
     if censorship is None:
       censorship = np.ones(N, dtype=bool)
@@ -113,7 +115,7 @@ def plot_dataframes(self, estimate):
 
         if "ax" not in kwargs:
             kwargs["ax"] = plt.figure().add_subplot(111)
-        kwargs['color'] = next( s for s in [kwargs.get('c'), kwargs.get('color'), kwargs["ax"]._get_lines.color_cycle.next()] if s )
+        kwargs['color'] = next( s for s in [kwargs.get('c'), kwargs.get('color'), next(kwargs["ax"]._get_lines.color_cycle)] if s )
 
         if flat:
             ci_force_lines=True
